* for this to run you need to install 
* tabplot (SSC)
* spineplot (SJ) 
* devnplot (SSC) 
* trimmean (SSC) 
* qplot (SJ) 
* stripplot (SSC)
* sparkline (SSC) 
* catplot (SSC) 

set scheme s1color 

u berkeley, clear

gen admitted = 1 - decision 
gen text = "30.4" if female & admitted
replace text = "69.6" if female & !admitted
replace text = "44.5" if !female & admitted
replace text = "55.5" if !female & !admitted
gen text2 = text + "%" 

* presentation p.12 
tabplot decision female, percent(female) ///
showval(text2, mlabcolor(black) mlabsize(*1.2)) ///
xtitle("") subtitle("") separate(admitted) ///
bar1(bfcolor(bg) blcolor(black)) bar2(bfcolor(green*0.4) blcolor(green)) 

* presentation p.14 
spineplot decision female, bar2(bfcolor(green*0.4) blcolor(green)) ///
bar1(bfcolor(bg) blcolor(black)) ///
text(text2, mlabsize(*2) mlabcolor(black)) plotregion(margin(zero)) ///
xtitle("", axis(2)) percent ///
xtitle(percent by gender, axis(1)) /// 
yla(15.2 "admitted" 65.2 "rejected", ang(h) tlcolor(none) axis(1)) ///
legend(off) aspect(.95) 

gen one = 1 

* presentation p.17 
graph hbar (sum) one, over(decision) over(female) over(major) ///
ytitle(frequency) asyvars stack plotregion(lstyle(solid)) ///
bar(1, bfcolor(green*0.4) blcolor(green)) bar(2, bfcolor(none) blcolor(black))  

* presentation p.19 
graph dot (mean) admitted, over(female) over(major) ///
ytitle(admission rate (%)) linetype(line) lines(lw(vvthin) lc(gs14)) ///
plotregion(lstyle(solid)) ///
asyvars /// 
marker(1, mcolor(blue*2) ms(+) msize(*1.4)) ///
marker(2, mcolor(pink*2) ms(Oh) msize(*1.4)) ///
yla(0 .25 "25" .5 "50" .75 "75" 1 "100") 

drop one text*
contract *
reshape wide _freq decision, i(major female) j(admitted)
gen applicants = _freq0 + _freq1
gen rate = 100 * _freq1 / applicants

* presentation p.22 
scatter rate applicant if female, ms(none) mlabel(major) mlabpos(0) mlabcolor(pink) mlabsize(*1.3) || ///
scatter rate applicant if !female, ms(none) mlabel(major) mlabpos(0) mlabcolor(blue) mlabsize(*1.3)   ///
yla(, ang(h)) ytitle(admission rate (%)) xtitle(number of applicants) legend(off)                     ///
t2("females", color(pink) place(w)) t1("males", color(blue) place(w) size(medsmall))  

u hostility, clear 

* presentation p.31 
devnplot change 
* presentation p.33 
devnplot change treatment                      
* presentation p.34 
devnplot change treatment gender
* presentation p.35 
devnplot change treatment gender, separate(retaliation) ///
legend(order(1 "no retaliation" 2 "retaliation")) 

u short, clear 

egen group = group(page), label
gen tmean = .
qui forval i = 1/4 {
	trimmean parallax if group==`i', percent(25)
	replace tmean = r(tmean25) if group == `i'
}

* presentation p.40 
devnplot parallax page, level(tmean)

* presentation p.42 
qplot parallax, over(page) legend(ring(0) pos(5) col(1)) yla(, ang(h))

* presentation p.43 
qplot parallax, by(page, row(1)) yla(, ang(h))

* presentation p.45 
qplot parallax, by(page, row(1)) yla(, ang(h)) trscale(invnorm(@)) ///
xtitle(standard normal quantile)

gen group2 = group - 0.1

* presentation p.47 
stripplot parallax , over(page) width(0.1) stack ///
addplot(scatter group2 tmean) note(25% trimmed means shown)

* presentation p.49
histogram parallax, by(page, col(1)) freq width(0.5)

* presentation p.50
histogram parallax , by(page, col(1) caption(frequency, pos(12) place(w))) ///
frequency width(0.1) start(5.7) ///
subtitle(, ring(1) pos(9) nobox nobexpand) ytitle("") yla(, ang(h)) ///
blcolor(blue) bfcolor(blue*0.2)

* presentation p.53 
graph hbox parallax, over(page)

webuse grunfeld, clear 

* presentation p.58 
sparkline invest mvalue kstock year if company == 1

* presentation p.59 
sparkline invest year, by(company) extremes

* presentation p.60
sparkline invest mvalue kstock year, by(company, note("")) xtitle("") ///
extremes extremeslabel ysc(r(0.3 3.7))

u nightingale, clear 

label var y5 "zymotic disease"
label var y6 "wounds and injuries"
label var y7 "all other causes" 
local d1 xla(-1255.5 "1855" -1267.5 "1854" -1247.5 "1856", noticks labsize(*1.2)) 
local d2 xli(-1261.5 -1249.5, lc(gs12))
local s "size(*1.2)" 

* presentation p.62
line y5 y6 y7 date, title(Nightingale's data on mortality in the Crimea) ///
note(annualised rates per 1000)  `d1' `d2' ///
yla(0(200)1000, ang(h)) ///
lp(solid dash solid) lc(red blue black) legend(col(1) ring(0) pos(1)) xtitle("")

qui forval j = 5/7 {
	clonevar sqrty`j' = y`j' 
	replace sqrty`j' = sqrt(y`j') 
} 

* presentation p.63 
line sqrty? date, title(Nightingale's data on mortality in the Crimea) ///
note(annualised rates per 1000)  `d1' `d2' ///
yla(0 5 "25" 10 "100" 15 "225" 20 "400" 25 "625" 30 "900", ang(h)) ///
lp(solid dash solid) lc(red blue black) legend(col(1) ring(0) pos(1)) xtitle("")

* presentation p.65 
sparkline y5 y6 y7 date, title(Nightingale's data on mortality in the Crimea) ///
note(annualised rates per 1000) `d1' `d2' variablelabels xtitle("")  

u arcticseaice, clear 

* presentation p.67
line Extent doy if year>2001, c(L) by(year, note("") subtitle("`: var label extent'")) yla(, ang(h)) xla(1 "  1 Jan" 91 "1 Apr"  182 "1 Jul" 274 "1 Oct" 365 "31 Dec  ", labsize(*.8)) xtitle("") ysc(titlegap(*.25)) ytitle("") 

* presentation p.68 
line Extent doy if year>2001, c(L) subtitle("`: var label extent'  2002-13")  yla(, ang(h)) xla(1 "1 Jan" 91 "1 Apr"  182 "1 Jul" 274 "1 Oct" 365 "31 Dec") xtitle("") ysc(titlegap(*.25)) ytitle("") 

forval y = 2/13 {
	local Y = 2000 + `y'
	line Extent doy if year>2001, c(L) lc(gs12) title("`Y'")  yla(0(5)15, ang(h)) xla(1 "   1 Jan" 91 "1 Apr"  182 "1 Jul" 274 "1 Oct" 365 "31 Dec    ") xtitle("") ytitle("") || line Extent doy if year == `Y' , lc(blue) lw(*2) name(g`Y', replace) legend(off)
}

* presentation p.70 
graph combine g2002 g2003 g2004 g2005 g2006 g2007 g2008 g2009 g2010 g2011 g2012 g2013, imargin(vsmall) title(Arctic sea ice extent (million km{c 178})) 

forval j = 2/13 {
	graph drop g`=2000 + `j''
}

u titanic, clear

label def sex 0 f 1 m, modify
label def survived 0 died 1 survived, modify

* presentation p.73 
catplot survived sex class, by(age, note("")) fraction(age sex class) ///
nofill asyvars stack recast(bar) bar(1, bcolor(gray)) bar(2, bcolor(pink*0.3)) ///
yla(0 0.2 "0.2" 0.4 "0.4" 0.6 "0.6" 0.8 "0.8" 1, ang(h))


collapse (mean) survived (count) count=survived, by(class age sex)
gen label = word("1 2 3 C", class)
gen nsurvived = survived*count
egen num = total(nsurvived), by(age sex)
egen den = total(count), by(age sex)
gen ave = num/den
label def sex 0 female 1 male, modify

* presentation p.74 
devnplot survived age sex, sort(class) ///
mla(label label label label) ms(none ..) mlabpos(0 ..) mlabsize(*1.5 ..)  ///
mlabcolor(pink blue pink blue) /// 
level(ave) ytitle(fraction survived) yla(0 .2 "0.2" .4 "0.4" .6 "0.6" .8 "0.8" 1) ///
subtitle("level is weighted mean for age and sex", place(w) just(left)) ///
note("1,2,3,C = first, second, third class and crew") 

